embassy-nrf

Crates

git

Versions

nrf9161-ns

Flavors

Itatbdata0

Struct Itatbdata0 

#[repr(transparent)]
pub struct Itatbdata0(pub u32);
The ITATBDATA0 register performs different functions depending on whether the access is a read or a write.

Tuple Fields

0: u32

Implementations

Source

impl Itatbdata0

pub const fn atdata_0(&self) -> Atdata0

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_0(&mut self, val: Atdata0)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_1(&self) -> Atdata1

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_1(&mut self, val: Atdata1)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_2(&self) -> Atdata2

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_2(&mut self, val: Atdata2)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_3(&self) -> Atdata3

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_3(&mut self, val: Atdata3)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_4(&self) -> Atdata4

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_4(&mut self, val: Atdata4)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_5(&self) -> Atdata5

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_5(&mut self, val: Atdata5)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_6(&self) -> Atdata6

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_6(&mut self, val: Atdata6)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_7(&self) -> Atdata7

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_7(&mut self, val: Atdata7)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_8(&self) -> Atdata8

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_8(&mut self, val: Atdata8)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_9(&self) -> Atdata9

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_9(&mut self, val: Atdata9)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_10(&self) -> Atdata10

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_10(&mut self, val: Atdata10)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_11(&self) -> Atdata11

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_11(&mut self, val: Atdata11)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_12(&self) -> Atdata12

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_12(&mut self, val: Atdata12)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_13(&self) -> Atdata13

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_13(&mut self, val: Atdata13)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_14(&self) -> Atdata14

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_14(&mut self, val: Atdata14)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_15(&self) -> Atdata15

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_15(&mut self, val: Atdata15)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn atdata_16(&self) -> Atdata16

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.

pub const fn set_atdata_16(&mut self, val: Atdata16)

A read access returns the value of a pin on atdatas_x of the enabled port. A write access writes to the corresponding atdatam pin of the enabled port.