embassy-nrf

Crates

git

Versions

nrf9161-ns

Flavors

Priorityctrlreg

Struct Priorityctrlreg 

#[repr(transparent)]
pub struct Priorityctrlreg(pub u32);
The Priority_Ctrl_Reg register defines the order in which inputs are selected. Each 3-bit field is a priority for each particular slave interface.

Tuple Fields

0: u32

Implementations

Source

impl Priorityctrlreg

pub const fn priport0(&self) -> u8

Priority value of port number 0.

pub const fn set_priport0(&mut self, val: u8)

Priority value of port number 0.

pub const fn priport1(&self) -> u8

Priority value of port number 1.

pub const fn set_priport1(&mut self, val: u8)

Priority value of port number 1.

pub const fn priport2(&self) -> u8

Priority value of port number 2.

pub const fn set_priport2(&mut self, val: u8)

Priority value of port number 2.

pub const fn priport3(&self) -> u8

Priority value of port number 3.

pub const fn set_priport3(&mut self, val: u8)

Priority value of port number 3.

pub const fn priport4(&self) -> u8

Priority value of port number 4.

pub const fn set_priport4(&mut self, val: u8)

Priority value of port number 4.

pub const fn priport5(&self) -> u8

Priority value of port number 5.

pub const fn set_priport5(&mut self, val: u8)

Priority value of port number 5.

pub const fn priport6(&self) -> u8

Priority value of port number 6.

pub const fn set_priport6(&mut self, val: u8)

Priority value of port number 6.

pub const fn priport7(&self) -> u8

Priority value of port number 7.

pub const fn set_priport7(&mut self, val: u8)

Priority value of port number 7.